//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
/// \file electromagnetic/MicroElec-SEYv1/include/DetectorMessenger.hh
/// \brief Definition of the DetectorMessenger class
//
// $Id: DetectorMessenger.hh 84208 2014-10-10 14:44:50Z gcosmo $
//
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#ifndef DetectorMessenger_h
#define DetectorMessenger_h 1

#include "G4UImessenger.hh"
#include "globals.hh"

class DetectorConstruction;
class G4UIdirectory;
class G4UIcommand;
class G4UIcmdWithAString;
class G4UIcmdWithADoubleAndUnit;
class G4UIcmdWithADouble;
class G4UIcmdWithABool;
class G4UIcmdWithAnInteger;
class G4UIcmdWith3Vector;
class G4UIcmdWithoutParameter;

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

class DetectorMessenger: public G4UImessenger
{
  public:
  
    DetectorMessenger(DetectorConstruction* );
   ~DetectorMessenger();
    
    void SetNewValue(G4UIcommand*, G4String) override;
    
  private:
  
    DetectorConstruction*      fDetector;
    
    G4UIdirectory*             		  fTestemDir;
    G4UIdirectory*             		  fDetDir;    
    G4UIcmdWithAString*          fMaterCmd;
	G4UIcmdWithAString*		   fMaterSurfCmd;
	G4UIcmdWithAString*		   fMaterLayer1Cmd;
	G4UIcmdWithAString*		   fMaterLayer2Cmd;
	G4UIcmdWithAString*		   fMaterLayer3Cmd;
	G4UIcmdWithAString*		   fMaterLayer4Cmd;
    G4UIcmdWithADoubleAndUnit* fSizeCmd;
	G4UIcmdWithADoubleAndUnit* fWidthCmd;
	G4UIcmdWithADoubleAndUnit* fSizeSurfCmd;
	G4UIcmdWithADoubleAndUnit* fSizeLayer1Cmd;
	G4UIcmdWithADoubleAndUnit* fSizeLayer2Cmd;
	G4UIcmdWithADoubleAndUnit* fSizeLayer3Cmd;
	G4UIcmdWithADoubleAndUnit* fSizeLayer4Cmd;
	G4UIcmdWithoutParameter* UpdateCmd;
};

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#endif

